pub struct Graphics(/* private fields */);Implementations
Sourceimpl Graphics
impl Graphics
pub fn get() -> Self
pub fn get_ptr() -> *const playdate_graphics
Sourcepub fn with_context<F, T>(&self, bitmap: &mut Bitmap, f: F) -> Result<T, Error>
pub fn with_context<F, T>(&self, bitmap: &mut Bitmap, f: F) -> Result<T, Error>
Allows drawing directly into an image rather than the framebuffer, for example for drawing text into a sprite’s image.
pub fn get_frame(&self) -> Result<&'static mut [u8], Error>
pub fn get_display_frame(&self) -> Result<&'static mut [u8], Error>
pub fn get_debug_bitmap(&self) -> Result<Bitmap, Error>
pub fn get_framebuffer_bitmap(&self) -> Result<Bitmap, Error>
pub fn set_background_color(&self, color: LCDSolidColor) -> Result<(), Error>
pub fn set_draw_mode(&self, mode: LCDBitmapDrawMode) -> Result<(), Error>
pub fn mark_updated_rows(&self, range: RangeInclusive<i32>) -> Result<(), Error>
pub fn display(&self) -> Result<(), Error>
pub fn set_draw_offset(&self, offset: ScreenVector) -> Result<(), Error>
pub fn new_bitmap( &self, size: ScreenSize, bg_color: LCDColor, ) -> Result<Bitmap, Error>
pub fn load_bitmap(&self, path: &str) -> Result<Bitmap, Error>
pub fn new_bitmap_table( &self, count: usize, size: ScreenSize, ) -> Result<BitmapTable, Error>
pub fn load_bitmap_table(&self, path: &str) -> Result<BitmapTable, Error>
pub fn clear(&self, color: LCDColor) -> Result<(), Error>
pub fn draw_line( &self, p1: ScreenPoint, p2: ScreenPoint, width: i32, color: LCDColor, ) -> Result<(), Error>
pub fn fill_triangle( &self, p1: ScreenPoint, p2: ScreenPoint, p3: ScreenPoint, color: LCDColor, ) -> Result<(), Error>
pub fn draw_rect(&self, rect: ScreenRect, color: LCDColor) -> Result<(), Error>
pub fn fill_rect(&self, rect: ScreenRect, color: LCDColor) -> Result<(), Error>
pub fn draw_ellipse( &self, center: ScreenPoint, size: ScreenSize, line_width: i32, start_angle: f32, end_angle: f32, color: LCDColor, ) -> Result<(), Error>
pub fn fill_ellipse( &self, target: Option<&'_ mut Bitmap>, stencil: Option<&'_ mut Bitmap>, center: ScreenPoint, size: ScreenSize, line_width: i32, start_angle: f32, end_angle: f32, color: LCDColor, clip: LCDRect, ) -> Result<(), Error>
pub fn load_font(&self, path: &str) -> Result<Font, Error>
pub fn set_font(&self, font: &Font) -> Result<(), Error>
pub fn draw_text(&self, text: &str, position: ScreenPoint) -> Result<i32, Error>
pub fn get_text_width( &self, font: &Font, text: &str, tracking: i32, ) -> Result<i32, Error>
pub fn get_font_height(&self, font: &Font) -> Result<u8, Error>
pub fn get_system_text_width( &self, text: &str, tracking: i32, ) -> Result<i32, Error>